<?php
/*
    THE ONLY THING YOU HAVE TO CHANGE IS THE FOLLOWING VARIABLE
    MAKE SURE $owner_lnum IS SET TO THE PERSON WHO WILL BE UPLOADING
    THE CSV FILE.

    To use this script:
        - Upload index.php, CAS.php and the CAS folder to a web server
        - Put an L# in the $owner_lnum variable below
        - Visit the address where you put the files on the web adding ?u=u in order to see the upload form
            - For example, https://apps.lanecc.edu/grades/index.php?u=u
        - Upload the CSV file

    When a student visits the page on the web they will be redirected to Lane's Central Authentication Server (CAS).
    They will need to log in using their L#/Passphrase and will be shown their data.
*/

// Set the L# of the person who is allowed to upload CSV files to this app.
$owner_lnum = "0"; //L88888888

/*  START CAS code */
include_once("CAS.php");

phpCAS::setDebug();

// initialize phpCAS
phpCAS::client(CAS_VERSION_2_0, 'cas.lanecc.edu', 443, '/cas');

// no SSL validation for the CAS server
phpCAS::setNoCasServerValidation();

// force CAS authentication
phpCAS::forceAuthentication();

// at this step, the user has been authenticated by the CAS server
// and the user's login name can be read with phpCAS::getUser().

// logout if desired
if (isset($_REQUEST['logout'])) {
    phpCAS::logout();
}
/* END CAS code */

    // Set $lnumber to the LNumber returned from CAS and just display the information
    $lnumber = phpCAS::getUser();
?>

<html>
    <head>
        <style type="text/css">
            table {
                font-family: arial;
                font-size: 14px;
                border: 1px solid #1C6EA4;
                background-color: #EEEEEE;
                width: 100%;
                text-align: left;
                border-collapse: collapse;
            }
                table td {
                border: 1px solid #AAAAAA;
                padding: 5px 5px;
            }
                table td {
                font-size: 15px;
            }
                table tr:nth-child(even) {
                background: #BCCEDE;
            }

            .red { color: red; }
        </style>
    </head>

    <body>

<?php
// Handle the file upload
$uploaded = false;
if (!empty($_FILES['upload'])) {
    if ($_FILES["upload"]["error"] > 0) {
        echo "Error: " . $_FILES["upload"]["error"] . "<br />";
    } else {
        echo "Upload: " . $_FILES["upload"]["name"] . "<br />";
        echo "Type: " . $_FILES["upload"]["type"] . "<br />";
        echo "Size: " . ($_FILES["upload"]["size"] / 1024) . " Kb<br />";
        echo "Stored in: " . $_FILES["upload"]["tmp_name"] . "<br />";
    }
    move_uploaded_file($_FILES["upload"]["tmp_name"], "upload.csv") or die("Could not upload");
    $uploaded = true;
}
// End File Upload ===============

// Get the info from the CSV for a specific L#
if (file_exists("upload.csv")) {
    $rows=file("upload.csv");
}

$grade = null;
if ($rows && $lnumber) {
    $first_row=$rows[0];
    $labels=explode(",", $first_row);
    foreach ($rows as $row) {
        $data=explode(",", $row);
        if ($data[0] == $lnumber || $data[1] == $lnumber) {
            $grade=$data;
        }
    }
}
// End get info =================================

$title="Class Grade Projection";

/*
     Upload CSV form

     Lock it down so only the owner ($owner_lnum set at top) can upload a CSV
*/
if (phpCAS::getUser() == $owner_lnum) {
    if ($uploaded) {
        print("<font color='red'>Uploaded the data</font>");
    } else {
        print( "<form enctype=\"multipart/form-data\" action=\"index.php?u=u\" method=\"post\"> <input type=\"hidden\" name=\"MAX_FILE_SIZE\" value=\"30000\" /> COMMA separated file: <input name=\"upload\" type=\"file\" /> <input type=\"submit\" value=\"Upload File\" /> </form>" );
    }
}
    // End Upload Form ===========================================================

// Display the grade information for the student who just logged in via CAS
if (is_null($grade)) {
    if (isset($lnumber)) {
        print ("<p>&nbsp;</p><p>&nbsp;</p><p>&nbsp;</p><p>&nbsp;</p><h2 align='center' class='red'>LNumber not found!</h2>");
        echo "<h4 align='center' class='red'>IF THIS IS NOT A PRIVATE COMPUTER, PLEASE <a href='?logout'>LOG OUT</a> BEFORE YOU LEAVE THIS PAGE!</h4>";
    }

    if ($rows) {
        $content=$page->readAsText();
    } else {
        print( "<center><b>No information is available at this time.</b></center>" );
    }

    print( "<table border=0 width=100%><tr><td>" . $content . "</td></tr></table>" );
} else {
    print( "<h1 align=center>Current and Projected Grade in Class</h1><blockquote>" );
    print( "<table border=0 width='100%'>" );

    for ($i=0; $i<count($labels); $i++) {
        print( "<tr><td width='85%'><b>" . $labels[$i] . "</b></td><td width='15%' align=center>" . $grade[$i] . "</td></tr>" );
    }


    //print ("</table><br><center><input type=button name=Close value=Close onClick=\"javascript:document.location='index.php';\">");
    echo "<h4 align='center' class='red'>IF THIS IS NOT A PRIVATE COMPUTER, PLEASE <a href='?logout'>LOG OUT</a> BEFORE YOU LEAVE THIS PAGE!</h4>";
}
    // End Display Grade Info ==========================================================
?>
</body>
</html>
